@@ -1,22 +1,24 @@
+import logging
+from functools import lru_cache
+
+from .exception import GrabpyException
+from .io import FileParts
 from .request import Requester
 from .robots import RobotsParser
-from functools import lru_cache
-from uuid import uuid4
-import shutil
 
 
 class Grabber:
-    def __init__(self, useragent: str, retries: int = 3, verbose: bool = False) -> None:
+    def __init__(self, useragent: str, retries: int = 3) -> None:
         """Set retries to -1 to retry indefinitely"""
 
         self.robots_parser = RobotsParser(useragent)
-        self.requester = Requester(retries, verbose)
+        self.requester = Requester(retries)
 
     def __enter__(self) -> 'Grabber':
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
-        return
+    def __exit__(self, exc_type, exc_val, exc_tb) -> bool:
+        return True
 
     @lru_cache(maxsize=8, typed=True)
     def get(self, url: str) -> bytes:
@@ -36,11 +38,15 @@ class Grabber:
             return False
 
         delay: float = self.robots_parser.scrape_delay(parser)
-        temp: str = f'{uuid4()}.parts'
 
-        with open(temp, 'wb') as f:
-            self.requester.stream(url, delay, f)
+        try:
+            content_length: int = self.requester.get_content_length(url, delay)
 
-        shutil.move(temp, fp)
-
-        return True
+            with FileParts(fp, content_length) as file:
+                for offset, chunk in self.requester.stream(url, content_length, delay):
+                    file.write(offset, chunk)
+        except GrabpyException as err:
+            logging.error('%s', err)
+            return False
+        else:
+            return True
